      subroutine fsfkk(u1,n1,p1,u2,n2,p2,u,n,p,ip,g,mass,wdth)
c----------------------------------------------------------------------c
c Returns a fermion array: 
c           u=u1*(gsm*P- + gsp*P+)*u2//(q^2-m2).
c
c Input: u1 - fermion,
c        u2 - scalar,
c        n1,n2,n - numbers of polarization states,
c        p1,p2 - momenta,
c        g - a scalar-fermion coupling,
c        mass, wdth - mass and width of u.
c        ip=+1/-1 for u representing a particle/an antiparticle
c Output: u - fermion array,
c         p - its momentum.
c
c The gamma matrices are taken in the Weyl representation as in the 
c paper by K. Kolodziej, M. Zralek, Phys. Rev. D43 (1991) 3619
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 17 May, 2007 (based on fhfkk.f); modified on 23 May, 2007
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)
      integer :: n1,n2,n,ip,i1,i2,i
      real(dp), dimension(0:3) :: p1,p2,p
      real(dp) :: mass,wdth
      complex(dp) :: g(2),u1(4,n1),u2(1,n2),u(4,n),
     &               mf,mf2,den,gp,gm,mgp,mgm,ubem(2),ubep(2)
      complex(dp), dimension(4) :: pp,pm

      p=p1+p2

      mf2=cmplx(mass**2,-mass*wdth,dp)
      mf=sqrt(mf2)

      pp=ip*(/cmplx(p(0)-p(3),0.d0,dp),   ! (1,1)
     &        cmplx(-p(1),-p(2),dp),      ! (2,1)
     &        cmplx(-p(1),p(2),dp),       ! (1,2)
     &        cmplx(p(0)+p(3),0.d0,dp) /) ! (2,2)

      pm=(/pp(4),-pp(2),-pp(3),pp(1)/)

      den=pp(1)*pp(4)-pp(3)*pp(2)-mf2

      gp=g(1)/den
      gm=g(2)/den
      mgp=mf*gp
      mgm=mf*gm

      i=0

      do i2=1,n2
       do i1=1,n1
        i=i+1

        ubem=(/u1(1,i1),u1(2,i1)/)*u2(1,i2)
        ubep=(/u1(3,i1),u1(4,i1)/)*u2(1,i2)

        u(:,i)=(/mgm*ubem(1)+gp*(ubep(1)*pm(1)+ubep(2)*pm(2)),
     &           mgm*ubem(2)+gp*(ubep(1)*pm(3)+ubep(2)*pm(4)),
     &           gm*(ubem(1)*pp(1)+ubem(2)*pp(2))+mgp*ubep(1),
     &           gm*(ubem(1)*pp(3)+ubem(2)*pp(4))+mgp*ubep(2)/)
       end do
      end do

      end subroutine fsfkk



