      subroutine kintwb(m1,m2,m3,x,p1,p2,p3,dlips)
c----------------------------------------------------------------------c
c Returns the four momenta and the phase space normalization for 
c a decay 1 -> 2 process in the rest frame of particle 1 
c The factor (2*pi)^-2 is not included in dlips.
c
c Input: ecm - the c.m.s. energy,
c        m1,m2,m3 - particle masses,
c        x(i) - random variables, 0 < x(i) < 1, i=1,2,
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 13 October, 2001; modified 18 January, 2003, 
c 6 May 2013, real(8) replaced with real(kind(1.d0))
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)

      real(dp) :: m1,m2,m3,x(2),dlips
      real(dp), dimension(0:3) :: p1,p2,p3
      real(dp), parameter :: pi=3.141592653589793238d0, zero=0.d0

c Local variables

      integer :: ifirst=1

      real(dp) :: dphi,dct,cps,lamsq,pp,ct,st,phi,cf,sf

      save ifirst,dphi,dct,cps

      if (ifirst == 1 ) then
       ifirst=0
       dphi=2.d0*pi
       dct=2.d0
       cps=dct*dphi/4.d0
      end if

      p1=(/m1,zero,zero,zero/)

      if (m1 < m2+m3) then
       dlips=zero
      else

       pp=sqrt(lamsq(m1,m2,m3))/(2.d0*m1)

       if (pp < zero) then
        dlips=zero
        return
       end if

       ct=dct*x(1)-1.d0
       st=sqrt(1.d0-ct**2)
       phi=dphi*x(2)
       cf=cos(phi)
       sf=sin(phi)


       p2=(/sqrt(m2**2+pp**2),pp*st*cf,pp*st*sf,pp*ct/)
       p3=(/sqrt(m3**2+pp**2),-p2(1),-p2(2),-p2(3)/)

       dlips=cps*pp/m1

      end if

      end


