      subroutine recpolkk(p,mass,imc,phi,u,npol)
c----------------------------------------------------------------------c
c Returns real polarization vectors in the rectangular basis.
c Input: p(0:3) - particle four mometum,
c        mass - particle mass.
c
c The polarization vectors are defined as in the paper by K. Kolodziej, 
c M. Zralek, Phys. Rev. D43 (1991) 3619:
c
c If imc=1 then polarizations are summed
c        exp(i*phi)*u(:,1) + exp(-i*phi)*u(:,2),  for a massless boson
c                    - " -              +u(:,3),  for a massive boson
c else
c   2 or 3 polarization vectors are returned for a massless or massive 
c   boson, respectively.
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 4 March, 1998;  modified on 22 March, 2006 (interface changed)
c                              6 May (interface changed again)
c                             19 October, 2007 (MC summing over 
c                                            polarizations implemented)
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)
      integer :: imc,npol

      real(dp), parameter :: zero=0.d0,one=1.d0
      real(dp) :: p(0:3),mass,phi,eps(0:3,3),gamma,ct,st,cf,sf,pp,pt
      complex(dp) :: u(0:3,npol)

      pt=sqrt(p(1)**2+p(2)**2)

      if (pt == zero) then

       pp=abs(p(3))
       ct=p(3)/pp
       st=zero
       cf=one
       sf=zero

      else

       pp=sqrt(pt**2+p(3)**2)
       ct=p(3)/pp
       st=sqrt(one-ct**2)
       cf=p(1)/pt
       sf=p(2)/pt

      end if



      if (abs(ct).lt.one) then

      eps(:,1)=(/ zero,
     &            ct*cf,
     &            ct*sf,
     &           -st /)

      eps(:,2)=(/ zero,
     &           -sf,
     &            cf,
     &            zero /)


      if (mass.gt.zero) then
        gamma=p(0)/mass
        eps(:,3)=(/ pp/mass,
     &             gamma*st*cf,
     &             gamma*st*sf,
     &             gamma*ct /)
      end if

      else if (ct.eq.one) then

      eps(:,1)=(/ zero,
     &            one,
     &            zero,
     &            zero /)

      eps(:,2)=(/ zero,
     &            zero,
     &            one,
     &            zero /)


      if (mass.gt.zero) then
        eps(:,3)=(/ pp/mass,
     &               zero,
     &               zero,
     &              p(0)/mass /)
      end if

      else if (ct.eq.-one) then

      eps(:,1)=(/ zero,
     &            one,
     &            zero,
     &            zero /)

      eps(:,2)=(/ zero,
     &            zero,
     &            -one,
     &            zero/)

      if (mass.gt.zero) then
        eps(:,3)=(/ pp/mass,
     &               zero,
     &               zero,
     &            -p(0)/mass /)

      end if

      end if


      if (imc == 1) then
       if (mass > 0.d0) then
        u(:,1)=cmplx(cos(phi)*(eps(:,1)+eps(:,2))+eps(:,3),
     &               sin(phi)*(eps(:,1)-eps(:,2)),dp)
       else
        u(:,1)=cmplx(cos(phi)*(eps(:,1)+eps(:,2)),
     &               sin(phi)*(eps(:,1)-eps(:,2)),dp)
       end if
      else
       u=cmplx(eps(:,1:npol),zero,dp)
      end if


      end subroutine

