      subroutine twbxx(p1,p2,p3,mat2,mat2b)
c----------------------------------------------------------------------c
c Returns the squared matrix element mat2 averaged over initial spins 
c            and summed over final spins and colours of
c
c                  t(p1) -> W+(p2) + b(p3)       (mat2)
c                  t~(p1) -> W-(p2) + b~(p3)     (mat2b)
c
c with the anomalous Wtb coupling.
c Input: pi(0:3), i=1,...,3 - external particle momenta,
c
c The frame is defined as that p1=(m1,0,0,0)
c Massive vector bosons are taken in the unitary gauge and massless 
c in the Feynman gauge
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 13 October, 2001;  modified 16 January, 2003;
c 27 Jan., 2011: adjusted to be used in carlomat
c 9 Feb., 2001 corrected
c Modified 6 May, 2013: CP odd case added 
c----------------------------------------------------------------------c

      use inprms
      use couplsmkk
      use topan

      implicit none

      real(dp) :: mat2,mat2b
      real(dp), dimension(0:3) :: p1,p2,p3
      integer :: i1,i2,i3
c      complex(dp), dimension(2,2) :: xp2,yp2
c      real(dp), dimension(0:3,3) :: ewm
c      complex(dp), dimension(2,2,3) :: xwm,ywm
      complex(dp), dimension(4,2) :: u1,u3,u1b,u3b
      complex(dp), dimension(0:3,3) :: u2
      complex(dp), dimension(2,3,2) :: amp,amb

c External particle momenta in the spinor representation:

c      call spinr(p2,xp2,yp2)

c Spinors of the external fermions:
c t -> bW+:
      call spinorkk(p1,mt,1,-1,0,zero,u1,2)
      call spinorkk(p3,mb,1,1,0,zero,u3,2)
      if (iwtb == 2) then
c t~ -> b~W-:
       call spinorkk(p1,mt,-1,-1,0,zero,u1b,2)
       call spinorkk(p3,mb,-1,1,0,zero,u3b,2)
      end if

c Polarization vectors of W-:

c      call recpol(p2,ps2,mw,ewm)
c      call recpol(p2,mw,ewm) ! 26 Jan., 2011
      call recpolkk(p2,mw,0,zero,u2,3)

c      do i2=1,3
c       ewm(:,i2)=u2(:,i2)
c       call spinr(ewm(:,i2),xwm(:,:,i2),ywm(:,:,i2))
c      end do

c The anomalous Wtb coupling sandwiched between spinors and contracted
c with ewm:

c t -> bW+:
c      call fefan0(u3,xwm,ywm,wff,-xp2,-yp2,f1p,f1m,f2p/mw,f2m/mw,u1,
c     &                                                      amp,2,3,2)
      call fefan(u3,2,u2,3,p2,u1,2,1,wtb,amp)

      if (iwtb == 2) then
c t~ -> b~W-:
       call fefan(u1b,2,u2,3,p2,u3b,2,-1,wtb,amb)
      end if

c The spin averaged squared matrix element:

      mat2=zero
      mat2b=zero

      do i1=1,2
      do i2=1,3
      do i3=1,2
c       call bwtmd(p2,wtb,u3(:,i3),u2(:,i2),u1(:,i1),mat)
c       call twbmd(p2,wtb,u1(:,i1),u2(:,i2),u3(:,i3),mat)
c       call wtbmd(p2,wtb,u2(:,i2),u1(:,i1),u3(:,i3),mat)
c       call wbtmd(p2,wtb,u2(:,i2),u3(:,i3),u1(:,i1),mat)
c       call btwmd(p2,wtb,u3(:,i3),u1(:,i1),u2(:,i2),mat)
c       call tbwmd(p2,wtb,u1(:,i1),u3(:,i3),u2(:,i2),mat)
c       mat2=mat2+abs(mat)**2
       mat2=mat2+abs(amp(i1,i2,i3))**2
       if (iwtb == 2) then
        mat2b=mat2b+abs(amb(i1,i2,i3))**2
       end if
      end do
      end do
      end do

      mat2=mat2/2.d0
      if (iwtb == 2) then
       mat2b=mat2b/2.d0
      else
       mat2b=mat2
      end if

      end 



